#
# spec file for package python-hupper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-hupper
Version:        1.12.1
Release:        1.5
Summary:        An in-process file monitor
License:        MIT
Group:          Development/Languages/Python
URL:            https://pylonsproject.org/
# The _service download the source and repack without the docs folder
# that has CC noncommercial license.
Source:         hupper-%{version}.tar.xz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-watchdog
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%python_subpackages

%description
Hupper is an integrated process monitor that will track changes to any
imported Python files in sys.modules as well as custom paths.
When files are changed the process is restarted.

%prep
%autosetup -p1 -n hupper-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/hupper

%check
%pytest

%post
%python_install_alternative hupper

%postun
%python_uninstall_alternative hupper

%files %{python_files}
%python_alternative %{_bindir}/hupper
%license %{python_sitelib}/hupper-%{version}.dist-info/LICENSE.txt
%{python_sitelib}/hupper-%{version}.dist-info/
%{python_sitelib}/hupper/

%changelog
* Wed May 29 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.2.1:
  - Add support for Python 3.12.
  - Fix a blocking issue when shutting down on Windows.
  - Fix a race condition closing pipes when restarting the worker
    process. See https://github.com/Pylons/hupper/pull/83
  - Fix issues with watchman when the server shuts down unexpectedly
    and when subscriptions are canceled.
  - Add hupper.get_reloader().graceful_shutdown() which can be used
    within your own app to trigger a full shutdown of the worker as
    well as the monitoring. See
    https://github.com/Pylons/hupper/pull/88
  1.12:
  - When the reloader is stopped, exit with the same code received
    from the subprocess. See https://github.com/Pylons/hupper/pull/81
  1.11:
  - Drop support for Python 2.7, 3.4, 3.5, and 3.6.
  - Add support/testing for Python 3.10, and 3.11.
  - Explicitly require reload_interval set greater than 0 to avoid
    spinning the CPU needlessly.
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- 1.10.3 (2021-05-13)
  Support Python 3.8 and 3.9.
  Fix an issue with bare .pyc files in the source folder causing unhandled exceptions. See https://github.com/Pylons/hupper/pull/69
  Fix issues with using the Watchman file monitor on versions newer than Watchman 4.9.0. This fix modifies hupper to use Watchman’s
  watch-project capabilities which also support reading the .watchmanconfig file to control certain properties of the monitoring.
  See https://github.com/Pylons/hupper/pull/70
* Thu Apr  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.10.2
  * Support --shutdown-interval on the hupper CLI.
  * Support --reload-interval on the hupper CLI.
  * Do not choke when stdin is not a TTY while waiting for changes after a crash.
  * Fix deprecation warnings caused by using the imp module on newer versions of Python.
  * Avoid acquiring locks in the reloader process's signal handlers.
  * Handle a SIGTERM signal by forwarding it to the child process and
    gracefully waiting for it to exit. This should enable using hupper
    from within docker containers and other systems that want to control
    the reloader process.
* Sat Jan 11 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Use pyproject_install macro (boo#1094323)
* Mon Aug  5 2019 pgajdos@suse.com
- version update to 1.8.1
  * Do not show the ``KeyboardInterrupt`` stacktrace when killing ``hupper``
    while waiting for a reload.
  * If the worker process crashes, ``hupper`` can be forced to reload the worker
    by pressing the ``ENTER`` key in the terminal instead of waiting to change a
    file.
    See https://github.com/Pylons/hupper/pull/53
  * On Python 3.5+ support recursive glob syntax in ``reloader.watch_files``.
    See https://github.com/Pylons/hupper/pull/52
* Sun May 19 2019 Todd R <toddrme2178@gmail.com>
- Switch to wheel, which doesn't have the problematic
  CC-noncomercial licensed documentation.
* Tue May  7 2019 pgajdos@suse.com
- version update to 1.6.1
  * lot of changes, see CHANGES.rst
- remove -doc
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Jul 14 2017 aloisio@gmx.com
- Initial package (1.0)
